from setuptools import setup

setup(name='CarvePie',
      version='0.2',
      description='Python helper for python ninja',
      url='http://github.com/saqirzzq/CarvePy',
      author='Saqib Razzaq',
      author_email='saqi.cb@gmail.com',
      license='MIT',
      packages=['CarvePie'],
      zip_safe=False)